@@ -4,5 +4,5 @@
 # Fenrir TTY screen reader
 # By Chrys, Storm Dragon, and contributers.
 
-version = "2024.12.20"
-codeName = "stable"
+version = "2025.02.26"
+codeName = "master"
